# Pinterest changelog

## [0.1.2] - 2026-03-12
- Updated connector definition (YAML version 0.1.1)
- Source commit: b541ca65
- SDK version: 0.1.0

## [0.1.1] - 2026-03-11
- Updated connector definition (YAML version 0.1.1)
- Source commit: 44677ecb
- SDK version: 0.1.0

## [0.1.0] - 2026-03-06
- Updated connector definition (YAML version 0.1.1)
- Source commit: 4b20ee21
- SDK version: 0.1.0
